import { ChangeDetectionStrategy, Component, inject, OnInit, signal } from '@angular/core';
import { GameInfoComponent } from '@blackjack/components/game-info/game-info.component';
import { AuthService } from '@service/auth.service';
import { AudioService } from '@shared/services/audio.service';

@Component({
  selector: 'app-coinflip',
  standalone: true,
  imports: [GameInfoComponent],
  templateUrl: './coinflip.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export default class CoinflipComponent implements OnInit {
  currentBet = signal(0);
  balance = signal(0);
  gameInProgress = signal(false);
  isActionInProgress = signal(false);
  audioService = inject(AudioService);
  authService = inject(AuthService);

  onNewGame(bet: number): void {
    this.isActionInProgress.set(true);
    this.audioService.playBetSound();
  }

  ngOnInit(): void {
    // Subscribe to user updates for real-time balance changes
    this.authService.userSubject.subscribe((user) => {
      if (user) {
        this.balance.set(user.balance);
      }
    });
  }
}
